@@ -1,12 +1,12 @@
 from .postgres_handler import Postgres_Handler as pg_handler
 
 class Database_Handler:
-    def __init__(self, db_type, user_name, password, host, port):
+    def __init__(self, db_type, user_name, password, host, port,database):
         self.db_type = db_type
-        self.__build_connection(user_name, password, host, port)
+        self.__build_connection(user_name, password, host, port,database)
 
-    def __build_connection(self, user_name, password, host, port):
-        self.handler = pg_handler(user_name, password, host, port)
+    def __build_connection(self, user_name, password, host, port, database):
+        self.handler = pg_handler(user_name, password, host, port, database)
     
     def add_sql_props(self, columns, keywords, base_query):
         self.handler.define_columns(columns)
