@@ -4,12 +4,12 @@ import json
 
 class Postgres_Handler(Sql_Handler):
     #Initializer that takes the values for connection
-    def __init__(self, user_name, password, host, port):
+    def __init__(self, user_name, password, host, port, database):
         self.user_name = user_name
         self.password = password
         self.host = host
         self.port = port
-        
+        self.database = database
     #Methods from inherited abstract class
     def define_columns(self, columns):
         super().define_columns(columns)
